.. _github-stats-3-3-0:

GitHub Stats for Matplotlib 3.3.0
=================================

GitHub stats for 2020/03/03 - 2020/07/16 (tag: v3.2.0)

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 198 issues and merged 1066 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/48?closed=1>`__

The following 144 authors contributed 3829 commits.

* Adam
* Adam Paszke
* Adam Ruszkowski
* Alex Henrie
* Alexander Rudy
* Amy Roberts
* andrzejnovak
* Antony Lee
* Ardie Orden
* Asaf Maman
* Avni Sharma
* Ben Root
* Bruno Beltran
* Bruno Pagani
* chaoyi1
* Cho Yin Yong
* Chris
* Christoph Pohl
* Cimarron Mittelsteadt
* Clemens Brunner
* Dan Hickstein
* Dan Stromberg
* David Chudzicki
* David Stansby
* Dennis Tismenko
* Dominik Schmidt
* donchanee
* Dora Fraeman Caswell
* Edoardo Pizzigoni
* Elan Ernest
* Elliott Sales de Andrade
* Emlyn Price
* Eric Firing
* Eric Larson
* Eric Relson
* Eric Wieser
* Fabien Maussion
* Frank Sauerburger
* Gal Avineri
* Generated images
* Georg Raiser
* Gina
* Greg Lucas
* hannah
* Hanno Rein
* Harshal Prakash Patankar
* henryhu123
* Hugo van Kemenade
* Ian Hincks
* ImportanceOfBeingErnest
* Inception95
* Ingo Fründ
* Jake Lee
* Javad
* jbhopkins
* Jeroonk
* jess
* Jess Tiu
* jfbu
* Jiahao Chen
* Jody Klymak
* Jon Haitz Legarreta Gorroño
* Jose Manuel Martí
* Joshua Taillon
* Juanjo Bazán
* Julian Mehne
* Kacper Kowalik (Xarthisius)
* Kevin Mader
* kolibril13
* kopytjuk
* ksafran
* Kyle Sunden
* Larry Bradley
* Laurent Thomas
* Lawrence D'Anna
* Leo Singer
* lepuchi
* Luke Davis
* Manan Kevadiya
* Manuel Nuno Melo
* Maoz Gelbart
* Marat K
* Marco Gorelli
* Matt Newville
* Matthias Bussonnier
* Max
* Max Chen
* Max Humber
* Maximilian Nöthe
* Michaël Defferrard
* Michele Mastropietro
* mikhailov
* MuhammadFarooq1234
* Mykola Dvornik
* Nelle Varoquaux
* Nelson Darkwah Oppong
* Nick Pope
* Nico Schlömer
* Nikita Kniazev
* Olivier Castany
* Omar Chehab
* Paul Gierz
* Paul Hobson
* Paul Ivanov
* Pavel Fedin
* Peter Würtz
* Philippe Pinard
* pibion
* Po
* Pradeep Reddy Raamana
* Ram Rachum
* ranjanm
* Raphael
* Ricardo Mendes
* Riccardo Di Maio
* Ryan May
* Sadie Louise Bartholomew
* Sairam Pillai
* Samesh Lakhotia
* SamSchott
* Sandro Tosi
* Siddhesh Poyarekar
* Sidharth Bansal
* Snowhite
* SojiroFukuda
* Spencer McCoubrey
* Stefan Mitic
* Stephane Raynaud
* Steven G. Johnson
* Steven Munn
* Ted Drain
* Terence Honles
* Thomas A Caswell
* Thomas Robitaille
* Till Stensitzki
* Tim Hoffmann
* Todd Jennings
* Tyrone Xiong
* Umar Javed
* Venkada
* vishalBindal
* Vitaly Buka
* Yue Zhihan
* Zulko

GitHub issues and pull requests:

Pull Requests (1066):

* :ghpull:`17943`: Backport PR #17942 on branch v3.3.x (Increase heading level for 3.3 What's New)
* :ghpull:`17942`: Increase heading level for 3.3 What's New
* :ghpull:`17941`: Backport PR #17938 on branch v3.3.x (Don't allow 1D lists as subplot_moasic layout.)
* :ghpull:`17940`: Backport PR #17885 on branch v3.3.x (BF: ignore CLOSEPOLY after NaN in PathNanRemover)
* :ghpull:`17937`: Backport PR #17877 on branch v3.3.x (Fix drawing zoom rubberband on GTK backends.)
* :ghpull:`17938`: Don't allow 1D lists as subplot_moasic layout.
* :ghpull:`17885`: BF: ignore CLOSEPOLY after NaN in PathNanRemover
* :ghpull:`17877`: Fix drawing zoom rubberband on GTK backends.
* :ghpull:`17933`: Backport PR #17858 on branch v3.3.x (Refresh what's new page for 3.3.0)
* :ghpull:`17858`: Refresh what's new page for 3.3.0
* :ghpull:`17919`: Backport PR #17913 on branch v3.3.x (Revert using SVG inheritance diagrams)
* :ghpull:`17913`: Revert using SVG inheritance diagrams
* :ghpull:`17911`: Backport PR #17907 on branch v3.3.x (Fix release() method name in macosx backend)
* :ghpull:`17907`: Fix release() method name in macosx backend
* :ghpull:`17903`: Backport PR #17859 on branch v3.3.x (API: resolve unset vmin / vmax in all ScalarMapple based methods)
* :ghpull:`17859`: API: resolve unset vmin / vmax in all ScalarMapple based methods
* :ghpull:`17898`: Backport PR #17882 on branch v3.3.x (Fix FFMpegBase.isAvailable with detached terminals.)
* :ghpull:`17882`: Fix FFMpegBase.isAvailable with detached terminals.
* :ghpull:`17881`: Backport PR #17871 on branch v3.3.x (Mention single char colors shading in more places)
* :ghpull:`17871`: Mention single char colors shading in more places
* :ghpull:`17872`: Backport PR #17800 on branch v3.3.x (Increase tolerance for alternate architectures)
* :ghpull:`17800`: Increase tolerance for alternate architectures
* :ghpull:`17861`: Revert "Fix linewidths and colors for scatter() with unfilled markers"
* :ghpull:`17864`: Backport PR #17862 on branch v3.3.x (CI: Install, or upgrade, Python 3 on homebrew.)
* :ghpull:`17846`: Backport PR #17844 on branch v3.3.x (Explain why Qt4 backends are deprecated)
* :ghpull:`17844`: Explain why Qt4 backends are deprecated
* :ghpull:`17833`: Backport PR #17831 on branch v3.3.x (BLD: default to system freetype on AIX)
* :ghpull:`17831`: BLD: default to system freetype on AIX
* :ghpull:`17823`: Backport PR #17821 on branch v3.3.x (FIX: Keep lists of lists of one scalar each 2D in _reshape_2D)
* :ghpull:`17821`: FIX: Keep lists of lists of one scalar each 2D in _reshape_2D
* :ghpull:`17811`: Backport PR #17797 on branch v3.3.x (Fix running contour's test_internal_cpp_api directly.)
* :ghpull:`17812`: Backport PR #17772 on branch v3.3.x (Partially fix rubberbanding in GTK3.)
* :ghpull:`17815`: Backport PR #17814 on branch v3.3.x (Don't duplicate deprecated parameter addendum.)
* :ghpull:`17814`: Don't duplicate deprecated parameter addendum.
* :ghpull:`17772`: Partially fix rubberbanding in GTK3.
* :ghpull:`17797`: Fix running contour's test_internal_cpp_api directly.
* :ghpull:`17809`: Backport PR #17801 on branch v3.3.x (BUG: Fix implementation of _is_closed_polygon)
* :ghpull:`17801`: BUG: Fix implementation of _is_closed_polygon
* :ghpull:`17796`: Backport PR #17764 on branch v3.3.x (FIX: be more careful about not importing pyplot early)
* :ghpull:`17795`: Backport PR #17781 on branch v3.3.x (Fix limit setting after plotting empty data)
* :ghpull:`17764`: FIX: be more careful about not importing pyplot early
* :ghpull:`17781`: Fix limit setting after plotting empty data
* :ghpull:`17787`: Backport PR #17784 on branch v3.3.x (Allow passing emtpy list of ticks to FixedLocator)
* :ghpull:`17784`: Allow passing empty list of ticks to FixedLocator
* :ghpull:`17766`: Backport PR #17752 on branch v3.3.x (Numpydoc-ify various functions)
* :ghpull:`17752`: Numpydoc-ify various functions
* :ghpull:`17762`: Backport PR #17742 on branch v3.3.x (Update tricontour[f] docs)
* :ghpull:`17742`: Update tricontour[f] docs
* :ghpull:`17760`: Backport PR #17756 on branch v3.3.x (Fix tk tooltips for dark themes.)
* :ghpull:`17756`: Fix tk tooltips for dark themes.
* :ghpull:`17747`: Backport PR #17731 on branch v3.3.x ("Fix" tight_layout for template backend.)
* :ghpull:`17731`: "Fix" tight_layout for template backend.
* :ghpull:`17739`: Backport PR #17734 on branch v3.3.x (Oversample thumbnail x2)
* :ghpull:`17734`: Oversample thumbnail x2
* :ghpull:`17738`: Backport PR #17729 on branch v3.3.x (Fix type doc for scroll event "step" attribute.)
* :ghpull:`17729`: Fix type doc for scroll event "step" attribute.
* :ghpull:`17724`: Backport PR #17720 on branch v3.3.x (Fix check for manager = None.)
* :ghpull:`17720`: Fix check for manager = None.
* :ghpull:`17719`: Backport PR #17693 on branch v3.3.x (DOC: Add svg2pdf converter for generating PDF docs.)
* :ghpull:`17693`: DOC: Add svg2pdf converter for generating PDF docs.
* :ghpull:`17718`: Backport PR #17715 on branch v3.3.x (Clarify gridspec error message for non-integer inputs.)
* :ghpull:`17717`: Backport PR #17705 on branch v3.3.x (Keep cachedRenderer as None when pickling Figure.)
* :ghpull:`17715`: Clarify gridspec error message for non-integer inputs.
* :ghpull:`17705`: Keep cachedRenderer as None when pickling Figure.
* :ghpull:`17701`: Backport PR #17687 on branch v3.3.x (Mention keyboard modifiers in toolbar tooltip texts.)
* :ghpull:`17687`: Mention keyboard modifiers in toolbar tooltip texts.
* :ghpull:`17698`: Backport PR #17686 on branch v3.3.x (Fix tooltip for wx toolbar.)
* :ghpull:`17686`: Fix tooltip for wx toolbar.
* :ghpull:`17692`: Backport PR #17680 on branch v3.3.x (MNT: migrate away from deprecated c-api)
* :ghpull:`17680`: MNT: migrate away from deprecated c-api
* :ghpull:`17688`: Backport PR #17676 on branch v3.3.x (FIX: correctly process the tick label size)
* :ghpull:`17676`: FIX: correctly process the tick label size
* :ghpull:`17677`: Backport PR #17664 on branch v3.3.x (Clarify docs of AutoDateLocator.intervald)
* :ghpull:`17678`: Backport PR #17665 on branch v3.3.x (Document that some single char colors are shaded)
* :ghpull:`17679`: Backport PR #17675 on branch v3.3.x (DOC: specify that the LaTeX installation needs to include cm-super)
* :ghpull:`17675`: DOC: specify that the LaTeX installation needs to include cm-super
* :ghpull:`17665`: Document that some single char colors are shaded
* :ghpull:`17664`: Clarify docs of AutoDateLocator.intervald
* :ghpull:`17672`: Backport PR #17668 on branch v3.3.x (Don't pass "wrong" ``indent=False`` in SVG generation.)
* :ghpull:`17671`: Backport PR #17667 on branch v3.3.x (Don't linewrap css in svg header.)
* :ghpull:`17668`: Don't pass "wrong" ``indent=False`` in SVG generation.
* :ghpull:`17667`: Don't linewrap css in svg header.
* :ghpull:`17666`: Prepare for 3.3.0 rc1
* :ghpull:`17663`: DOC: update the gh stats for v3.3.0
* :ghpull:`17656`: Fix default colouring of Shadows
* :ghpull:`17657`: V3.2.x mergeup
* :ghpull:`17623`: Add a flag for disabling LTO.
* :ghpull:`17569`: Delay \usepackage{textcomp} until after the custom tex preamble.
* :ghpull:`17416`: Reorder NavigationToolbar2 methods.
* :ghpull:`17604`: DOC: Clarify offset notation and scientific notation
* :ghpull:`17617`: Rewrite pdf test to use check_figures_equal.
* :ghpull:`17654`: Small fixes to recent What's New
* :ghpull:`17649`: MNT: make _setattr_cm more forgiving
* :ghpull:`17644`: Doc 33 whats new consolidation
* :ghpull:`17647`: Fix example in docstring of cbook._unfold.
* :ghpull:`10187`: DOC: add a blitting tutorial
* :ghpull:`17471`: Removed idiomatic constructs from interactive figures docs
* :ghpull:`17639`: DOC: Update colormap deprecation warning to use Python's copy function.
* :ghpull:`17223`: Warn on invalid savefig keyword arguments
* :ghpull:`17625`: Give _DummyAxis instances a __name__
* :ghpull:`17636`: Fix image vlim clipping again
* :ghpull:`17635`: Fix autoscaling with tiny sticky values.
* :ghpull:`17620`: MNT: make _setattr_cm more conservative
* :ghpull:`17621`: FIX: restore ability to pass a tuple to axes_class in axes_grid
* :ghpull:`16603`: axes collage
* :ghpull:`17622`: Fix typo in description of savefig.bbox.
* :ghpull:`17619`: Skip test_tmpconfigdir_warning when running as root.
* :ghpull:`17610`: MNT: allow 0 sized figures
* :ghpull:`17163`: Fix clipping of markers in PDF backend.
* :ghpull:`17556`: DOC: Update contributor listing in credits
* :ghpull:`17221`: Add metadata saving support to SVG.
* :ghpull:`17603`: Replace image comparison in test_axes_grid1 by geometry checks.
* :ghpull:`17428`: Doc start 33 merges
* :ghpull:`17607`: Convert adjust_bbox to use ExitStack.
* :ghpull:`17575`: DOCS: update collections.py docstrings to current doc conventions
* :ghpull:`15826`: Fix bar3d bug with matching color string and array x lengths
* :ghpull:`14507`: Simplify handling of Qt modifier keys.
* :ghpull:`17589`: Fix doc build with Sphinx < 3.
* :ghpull:`17590`: Clarify docs of set_powerlimits()
* :ghpull:`17597`: MNT: cleanup minor style issues
* :ghpull:`17183`: Update configuration of CircleCI builds
* :ghpull:`17592`: Improve docstrings of ScalarFormatter
* :ghpull:`17456`: Improve stackplot example
* :ghpull:`17545`: Improve docs of markers
* :ghpull:`17233`: Improve PDF metadata support in PGF
* :ghpull:`17086`: Remove jQuery & jQuery UI
* :ghpull:`17580`: Fix same_color() for 'none' color
* :ghpull:`17582`: Fix link in doc
* :ghpull:`17491`: DOC: Only link to overall Zenodo DOI.
* :ghpull:`17515`: FIX: add set_box_aspect, improve tight bounding box for Axes3D + fix bbox_inches support with fixed box_aspect
* :ghpull:`17581`: DOC: Remove duplicate Returns in subplot2grid.
* :ghpull:`17550`: Update subplot2grid doc to use Figure.add_gridspec, not GridSpec.
* :ghpull:`17544`: markerfacecolor should not override fillstyle='none' in plot()
* :ghpull:`15672`: Remove mention that tkagg was derived from PIL.
* :ghpull:`17573`: Examples: fix formatting issue in 'Errorbar limit selection'
* :ghpull:`17543`: Fix linewidths and colors for scatter() with unfilled markers
* :ghpull:`17448`: Add example for drawing an error band around a curve
* :ghpull:`17572`: Examples: clarity for 'set and get' example page
* :ghpull:`17276`: Allow numpy arrays in markevery
* :ghpull:`17536`: Consolidate some tests and fix a couple typos
* :ghpull:`17558`: Simplify plot_date()
* :ghpull:`17534`: Fmaussion extended boundary norm
* :ghpull:`17540`: Fix help window on GTK.
* :ghpull:`17535`: Update docs on subplot2grid / SubplotBase
* :ghpull:`17510`: Fix exception handling in FT2Font init.
* :ghpull:`16953`: Changed 'colors' paramater in PyPlot vlines/hlines and Axes vlines/hlines to default to configured rcParams 'lines.color' option
* :ghpull:`17459`: Use light icons on dark themes for wx and gtk, too.
* :ghpull:`17539`: Use symbolic icons for buttons in GTK toolbar.
* :ghpull:`15435`: Reuse png metadata handling of imsave() in FigureCanvasAgg.print_png().
* :ghpull:`5034`: New "extend" keyword to colors.BoundaryNorm
* :ghpull:`17532`: DOC: correct legend.title_fontsize docstring
* :ghpull:`17531`: Remove unneeded check/comment re: multiprocessing in setup.py.
* :ghpull:`17522`: Privatize ttconv module.
* :ghpull:`17517`: Make sure _parent is in sync with Qt parent in NavigationToolbar2QT
* :ghpull:`17525`: DOC/API: set __qualname__ when using class factory
* :ghpull:`17511`: Fix offset legend tightbbox
* :ghpull:`16203`: Port fontconfig's font weight detection to font_manager.
* :ghpull:`17485`: Support marking a single artist as not-usetex.
* :ghpull:`17338`: Support url on more Artists in svg
* :ghpull:`17519`: Prefer demo'ing rcParams rather than rc in examples.
* :ghpull:`13457`: Give ``AnnotationBbox`` an opinion about its extent
* :ghpull:`15037`: Simplifications to errorbar().
* :ghpull:`17493`: Update SVGs that use interpolation='none'.
* :ghpull:`15221`: Don't fallback to agg in tight_layout.get_renderer.
* :ghpull:`17512`: DOC: remove inkscape restriction in doc
* :ghpull:`17484`: Deprecate ismath parameter to draw_tex and ismath="TeX!".
* :ghpull:`17492`: Correctly set default linewidth for unfilled markers.
* :ghpull:`16908`: Adding 2d support to quadmesh set_array
* :ghpull:`17506`: Fix dicts unpacking for ``.plot``
* :ghpull:`17496`: Fix some incorrect image clipping
* :ghpull:`17340`: convert some sample plots to use plt.subplots() instead of other methods
* :ghpull:`17504`: Undocument parameter orientation of bar()
* :ghpull:`13884`: Add some documentation for axisartist's ExtremeFinder, plus some cleanups.
* :ghpull:`17495`: Fix Pillow import in testing.
* :ghpull:`17462`: Inline FigureCanvasGtkFoo._render_figure.
* :ghpull:`17474`: Numpydocify RectangleSelector docstring.
* :ghpull:`17003`: Optimize extensions with LTO and hidden visibility
* :ghpull:`17489`: BUG: Picking vertical line broken
* :ghpull:`17486`: Simplify handling of fontproperties=None.
* :ghpull:`17478`: Add support for blitting in qt5cairo.
* :ghpull:`15641`: Make get_sample_data autoload npy/npz files.
* :ghpull:`17481`: Fix LightSource.shade on fully unmasked array.
* :ghpull:`17289`: Prepare for ragged array warnings in NumPy 1.19
* :ghpull:`17358`: Fix masked CubicTriInterpolator
* :ghpull:`17477`: DOC: Use Sphinx-gallery animation capture
* :ghpull:`17482`: Shorten RectangleSelector._release.
* :ghpull:`17475`: Cleanup RectangleSelector example.
* :ghpull:`17461`: Deprecate the private FigureCanvasGTK3._renderer_init.
* :ghpull:`17464`: Fold _make_nseq_validator into _listify_validator.
* :ghpull:`17469`: Use qVersion, not QT_VERSION_STR -- the latter doesn't exist in PySide2.
* :ghpull:`4779`: DOC: Start to document interactive figures
* :ghpull:`17458`: Cleanup C++ code
* :ghpull:`17466`: DOC: clarify that milestones are intentions not approvals
* :ghpull:`17062`: Fix to "exported SVG files blurred in viewers"
* :ghpull:`17443`: Fix rcParams validator for dashes.
* :ghpull:`17350`: Move integerness checks to SubplotSpec._from_subplot_args.
* :ghpull:`17444`: Support odd-length dash patterns in Agg.
* :ghpull:`17405`: Show the failing line in bad-rcparams warnings.
* :ghpull:`17452`: Make validate_date throw ValueError, not RuntimeError.
* :ghpull:`17439`: Remove comment re: validation of datetime format strings.
* :ghpull:`17438`: Discourage use of proprietary Matplotlib names for freetype hinting
* :ghpull:`16990`: update testing helpers
* :ghpull:`16340`: Make set_x/ymargin() update axes limits, just like margins().
* :ghpull:`15029`: Get default params from matplotlibrc.template.
* :ghpull:`17363`: Fix toolbar separators in wx+toolmanager.
* :ghpull:`17348`: Avoid creating a Tick in Axis.get_tick_space.
* :ghpull:`15725`: Changed line color of boxplot for dark_background
* :ghpull:`17362`: Remove status bars in toolmanager mode as well.
* :ghpull:`16551`: DOC: be more opinionated about flags passed to pip
* :ghpull:`17328`: Fixes icon clipping issue with WxAgg NavigationToolbar2 for wxpython 4.1.0
* :ghpull:`17425`: fix typo in stem doc
* :ghpull:`17415`: Cygwin fixes
* :ghpull:`17401`: FIX: Fix for FFmpeg + GIF
* :ghpull:`16569`: MNT: improve the error message in Path init
* :ghpull:`17404`: Don't forget to dlclose() main_program in tkagg init.
* :ghpull:`17414`: Keep validate_date private.
* :ghpull:`17413`: Revert "DOC: drop the experimental tag constrained_layout and tight_layout"
* :ghpull:`17394`: Deprecate passing keys to update_keymap as single comma-separated string
* :ghpull:`17395`: TexManager fixes.
* :ghpull:`17399`: Remove qt4 backends from backend fallback candidates.
* :ghpull:`17392`: Clarify deprecation message re: tex/pgf preambles as list-of-strings.
* :ghpull:`17400`: Cleanup wx examples.
* :ghpull:`17378`: Fix marker overlap
* :ghpull:`17351`: Fix running the test suite with inkscape>=1.
* :ghpull:`17382`: FIX: properly check figure on gridspec
* :ghpull:`17390`: Small updates to troubleshooting guide.
* :ghpull:`15104`: Simplify file handling in ft2font.
* :ghpull:`17380`: Support standard names for freetype hinting flags.
* :ghpull:`15594`: Fix marker overlap
* :ghpull:`17372`: Auto-set artist.mouseover based on if get_cursor_data is overridden.
* :ghpull:`17377`: Remove code for sphinx < 1.8
* :ghpull:`17266`: Keep explicit ticklabels in sync with ticks from FixedLocator
* :ghpull:`17359`: Fix running test_internal_cpp_api directly.
* :ghpull:`17355`: Change subprocess for inkscape version detection
* :ghpull:`17369`: CI: Add eslint for JS linting
* :ghpull:`17226`: Replace backend_driver by new example runner.
* :ghpull:`17365`: Also use light color tool buttons in qt+toolmanager+dark theme.
* :ghpull:`17366`: Restrict Qt toolbars to top/bottom of canvas.
* :ghpull:`17361`: Remove randomness from test_colorbar_get_ticks_2.
* :ghpull:`17151`: Cleanup colors.py docstrings.
* :ghpull:`17287`: Make API of get_tightbbox more consistent between Axes and Axis.
* :ghpull:`17092`: Don't create a statusbar in Qt, wx backends.
* :ghpull:`17220`: Simplify Annotation and Text bbox drawing.
* :ghpull:`17353`: Make zooming work in qt-embedding example.
* :ghpull:`16727`: Update xtick.alignment parameter in rcsetup to validate against correct values
* :ghpull:`17236`: Add the "contour.linewidths" configuration option
* :ghpull:`16328`: Make Artist.set() apply properties in the order in which they are given.
* :ghpull:`9696`: FIX: set_url() without effect in the plot for instances of Tick
* :ghpull:`17002`: Fix AnnotationBbox picking and a bit of cleanup
* :ghpull:`17256`: Improve ps handling of individual usetex strings.
* :ghpull:`17267`: Improve image comparison decorator
* :ghpull:`17332`: Cleanup docstring of subplots().
* :ghpull:`16843`: Deprecate is_pyqt5.
* :ghpull:`15898`: New textcolor kwarg for legend
* :ghpull:`17333`: Make sharex, etc. args of subplots() keyword-only.
* :ghpull:`17329`: Improve docs of eventplot()
* :ghpull:`17330`: Remove pnpoly license.
* :ghpull:`13656`: For single datasets, don't wrap artist added by Axes.hist in silent_list
* :ghpull:`16247`: DOC added kwargs and tight_layout description in plt.figure
* :ghpull:`16992`: Implement FigureManager.resize for macosx backend
* :ghpull:`17324`: DOC: add offset axes to secondary_axes
* :ghpull:`17311`: Make pyplot signatures of rgrids() and thetagrids() explicit
* :ghpull:`17302`: Fix alignment of offset text on top axis.
* :ghpull:`14421`: Add GridSpec.subplots()
* :ghpull:`15111`: By default, don't change the figure face/edgecolor on savefig().
* :ghpull:`17318`: both x and y should multiply the radius
* :ghpull:`17309`: Cleanup parameter types in docstrings
* :ghpull:`17308`: Improve docs of bar() and barh()
* :ghpull:`17312`: changed axis to axes in lifecycle tutorial
* :ghpull:`16715`: Automatically create tick formatters for str and callable inputs.
* :ghpull:`16959`: Simplify and robustify ConnectionPatch coordinates conversion.
* :ghpull:`17306`: FIX: CL more stable
* :ghpull:`17301`: Use deprecate_privatize_attribute more.
* :ghpull:`16985`: Adds normalize kwarg to pie function
* :ghpull:`5243`: Enhancement of tick label offset text positioning
* :ghpull:`17292`: Deprecate various wx Toolbar attributes.
* :ghpull:`17297`: Simplify pickling support.
* :ghpull:`17298`: Fix rubberband in tk.
* :ghpull:`17299`: Avoid "dash motion" in qt zoom box.
* :ghpull:`17200`: Implement set_history_buttons for Tk toolbar.
* :ghpull:`16798`: Make the Qt interactive zoom rectangle black & white.
* :ghpull:`17296`: Fix doc wording
* :ghpull:`17282`: Don't divide by zero in Line2D.segment_hits.
* :ghpull:`17293`: Fix incorrect deprecation.
* :ghpull:`17285`: V32 mergeup
* :ghpull:`15933`: Warn if a temporary config/cache dir must be created.
* :ghpull:`15911`: Use os.getpid() in configdir, to avoid multiprocess concurrency issues
* :ghpull:`17277`: Move slow FontManager warning to FontManager constructor.
* :ghpull:`17222`: FIX: long titles x/ylabel layout
* :ghpull:`14960`: Don't generate individual doc entries for inherited Axes/Axis/Tick methods
* :ghpull:`17175`: Further sync axes_grid colorbars with standard colorbars.
* :ghpull:`17030`: Move widget functions into matplotlib.testing.widgets.
* :ghpull:`16975`: Fix "out of bounds" undefined behavior
* :ghpull:`17111`: Deprecate NavigationToolbar2._init_toolbar.
* :ghpull:`15275`: adds turbo colormap
* :ghpull:`17174`: Inline RGBAxes._config_axes to its only call site.
* :ghpull:`17156`: Deprecate text.latex.preview rcParam.
* :ghpull:`17242`: Make deprecations versions explicit
* :ghpull:`17165`: Small optimizations to scale and translate of Affine2D
* :ghpull:`17181`: Inline some private helper methods in ColorbarBase + small refactors.
* :ghpull:`17264`: Don't trigger save when gtk save dialog is closed by escape.
* :ghpull:`17262`: fix typo in set_clip_on doc
* :ghpull:`17234`: Shorten and privatize qt's UiSubplotTool.
* :ghpull:`17137`: Deprecate Toolbar.press/release; add helper to find overridden methods.
* :ghpull:`17245`: Improve error handling in _parse_scatter_color_args
* :ghpull:`15008`: ENH: add variable epoch
* :ghpull:`17260`: Text Rotation Example: Correct roation_mode typo
* :ghpull:`17258`: Improve info logged by tex subsystem.
* :ghpull:`17211`: Deprecate support for running svg converter from path contaning newline.
* :ghpull:`17078`: Improve nbAgg & WebAgg toolbars
* :ghpull:`17191`: Inline unsampled-image path; remove renderer kwarg from _check_unsampled_image.
* :ghpull:`17213`: Replace use of Bbox.bounds by appropriate properties.
* :ghpull:`17219`: Add support for suptitle() in tight_layout().
* :ghpull:`17235`: More axisartist cleanups
* :ghpull:`17239`: Remove deprecations that expire in 3.3
* :ghpull:`13696`: Deprecate offset_position="data".
* :ghpull:`16991`: Begin warning on modifying global state of colormaps
* :ghpull:`17053`: Replace most jQuery with vanilla JavaScript
* :ghpull:`17228`: Make params to pyplot.tight_layout keyword-only.
* :ghpull:`17225`: Remove Patch visibility tracking by Legend & OffsetBox.
* :ghpull:`17027`: Fix saving nbAgg figure after a partial blit
* :ghpull:`16847`: Ticks are not markers
* :ghpull:`17229`: Autogenerate subplots_adjust with boilerplate.py.
* :ghpull:`17209`: Simplify some axisartist code.
* :ghpull:`17204`: Draw unfilled hist()s with the zorder of lines.
* :ghpull:`17205`: Shorten tight_layout code.
* :ghpull:`17218`: Document ``Transform.__add__`` and ``.__sub__``.
* :ghpull:`17215`: Small cleanups.
* :ghpull:`17212`: Cleanup text.py.
* :ghpull:`17196`: Move polar tests to their own module.
* :ghpull:`14747`: Deprecate AxisArtist.dpi_transform.
* :ghpull:`13144`: Deprecate NavigationToolbar2GTK3.ctx.
* :ghpull:`17202`: DOC: Remove extra word
* :ghpull:`17194`: Small cleanups/simplifications/fixes to pie().
* :ghpull:`17102`: Switch tk pan/zoom to use togglable buttons.
* :ghpull:`16832`: Correctly compute path extents
* :ghpull:`17193`: Document docstring quote convention
* :ghpull:`17195`: Fix polar tests.
* :ghpull:`17189`: Make all parameters of ColorbarBase, except ``ax``, keyword-only.
* :ghpull:`16717`: Bugfix for issue 16501 raised ValueError polar subplot with (thetamax - thetamin) > 2pi
* :ghpull:`17180`: Doc: spines arrows example
* :ghpull:`17184`: Fix various small typos.
* :ghpull:`17143`: Move linting to GitHub Actions with reviewdog.
* :ghpull:`17160`: Correctly go through property setter when init'ing Timer interval.
* :ghpull:`17166`: Deprecate ScalarMappable.check_update and associated machinery.
* :ghpull:`17177`: Manually linewrap PS hexlines. Fixes #17176
* :ghpull:`17162`: Update docs of rc_context()
* :ghpull:`17170`: Convert SubplotZero example into centered-spines-with-arrows recipe.
* :ghpull:`17164`: Fix Figure.add_axes(rect=...).
* :ghpull:`17154`: DOC: Fix some warning and unreproducibility
* :ghpull:`17169`: Clarify that draw_event occurs after the canvas draw.
* :ghpull:`17089`: Cleanup some imports in tests
* :ghpull:`17040`: Improve docs on automated tests
* :ghpull:`17145`: CI: run pydocstyle with our custom options
* :ghpull:`16864`: Check parameter type for legend(labels)
* :ghpull:`17146`: FigureManager/NavigationToolbar2 cleanups.
* :ghpull:`16933`: Add tests for toolmanager.
* :ghpull:`17127`: ENH: allow title autopositioning to be turned off
* :ghpull:`17150`: Many docstring cleanups.
* :ghpull:`17148`: Fix most instances of D404 ("docstring should not start with 'this'").
* :ghpull:`17142`: BUGFIX: conditional for add_axes arg deprecation
* :ghpull:`17032`: Fold table.CustomCell into Cell.
* :ghpull:`17117`: TextBox improvements.
* :ghpull:`17108`: Make widgets.TextBox work also when embedding.
* :ghpull:`17135`: Simplify pan/zoom toggling.
* :ghpull:`17134`: Don't override update() in NavigationToolbar2Tk.
* :ghpull:`17129`: In docs remove 'optional' if 'default' can be given
* :ghpull:`16963`: Deprecate Locator.refresh and associated helpers.
* :ghpull:`17133`: Fix Button widget motion callback.
* :ghpull:`17125`: Make multiline docstrings start with a newline.
* :ghpull:`17124`: Widgets cleanup.
* :ghpull:`17123`: Cleanup/Simplify Cell._set_text_position.
* :ghpull:`16862`: FIX: turn off title autopos if pad is set
* :ghpull:`15214`: Inline wx icon loading.
* :ghpull:`16831`: Simplify interactive zoom handling.
* :ghpull:`17094`: DOC: drop the experimental tag constrained_layout and tight_layout
* :ghpull:`17101`: Avoid "wrapped C/C++ object has been deleted" when closing wx window.
* :ghpull:`17028`: Changed return type of get_{x,y}ticklabels to plain list
* :ghpull:`16058`: Deprecate {ContourSet,Quiver}.ax in favor of .axes.
* :ghpull:`15349`: Use checkboxes as bullet points for the PR review checklists
* :ghpull:`17112`: Fix some link redirects in docs
* :ghpull:`17090`: DOCS: add examples of how one "should" use Bbox
* :ghpull:`17110`: Simplify connection of the default key_press and button_press handlers.
* :ghpull:`17070`: Cleanups to Qt backend.
* :ghpull:`16776`: Make cursor text precision actually correspond to pointing precision.
* :ghpull:`17026`:  Add eslint & prettier, and re-format JS
* :ghpull:`17091`: Make sure slider uses "x" sign before multiplicative factor.
* :ghpull:`17082`: Cleanup TextBox implementation.
* :ghpull:`17067`: Simplify and generalize _set_view_from_bbox.
* :ghpull:`17081`: Update animation_api.rst
* :ghpull:`17077`: Improve default formatter for Slider values.
* :ghpull:`17079`: Use True instead of 1 for boolean parameters.
* :ghpull:`17074`: Fixed a typo in Lifecycle of a Plot
* :ghpull:`17072`: Cleanup multi_image example.
* :ghpull:`15287`: Allow sharex/y after axes creation.
* :ghpull:`16987`: Deprecate case-insensitive properties.
* :ghpull:`17059`: More missing refs fixes, and associated doc rewordings.
* :ghpull:`17057`: Simplify subgridspec example/tutorial.
* :ghpull:`17058`: Fix minor doc typos.
* :ghpull:`17024`: Clarify docs of Rectangle
* :ghpull:`17043`: Avoid spurious deprecation warning in TextBox.
* :ghpull:`17047`: Highlighted  .cbook.warn_deprecated() in contributing.rst
* :ghpull:`17054`: Use slope in axline example
* :ghpull:`17048`: More missing refs fixes.
* :ghpull:`17021`: File name made more understandable
* :ghpull:`16903`: Shorten implementation of Axes methods that just wrap Axis methods.
* :ghpull:`17039`: Cleanups to contour docs.
* :ghpull:`17011`: ci: Publish result images as Azure artifacts.
* :ghpull:`17038`: Improve readability of documenting_mpl.rst
* :ghpull:`16996`:  Clean up get_proj() docstring (used view_init docstring as reference)
* :ghpull:`17019`: Add return field to documentation of 'get_major_ticks'
* :ghpull:`16999`: Add section on artifacts to imshow docs
* :ghpull:`17029`: Fix table.Cell docstrings.
* :ghpull:`17025`: Fix RecursionError when closing nbAgg figures.
* :ghpull:`16971`: Don't change Figure DPI if value unchanged
* :ghpull:`16972`: Fix resize bugs in GTK
* :ghpull:`17008`: Change the description of Rectangle's xy parameter
* :ghpull:`16337`: Create axline() using slope
* :ghpull:`16947`: Fix missing parameter initialization in Axes.specgram()
* :ghpull:`17001`: Cleanup imshow_extent tutorial.
* :ghpull:`17000`: More stringent eventplot orientations.
* :ghpull:`16771`: Deprecate non-string values as legend labels
* :ghpull:`15910`: Simplify init of EventCollection.
* :ghpull:`16998`: Made INSTALL.rst consistent
* :ghpull:`15393`: Cleanup shape manipulations.
* :ghpull:`10924`: Clear() methods to Radio and CheckButtons and other improvements
* :ghpull:`16988`: Make plt.{r,theta}grids act as setters even when all args are kwargs.
* :ghpull:`16986`: update tox.ini to match pythons supported and allow flags for pytest
* :ghpull:`16111`: Move locking of fontlist.json *into* json_dump.
* :ghpull:`13110`: Slightly tighten the Bbox/Transform API.
* :ghpull:`16973`: TST: don't actually render 1k+ date ticks
* :ghpull:`16967`: Simplify animation writer fallback.
* :ghpull:`16812`: Bezier/Path API Cleanup: fix circular import issue
* :ghpull:`16968`: Add link to 3.2 min-supported-requirements.
* :ghpull:`16957`: Remove unused, private aliases Polygon._{get,set}_xy.
* :ghpull:`16960`: Improve error for quoted values in matplotlibrc.
* :ghpull:`16530`: Fix violinplot support list of pandas.Series
* :ghpull:`16939`: Cleanup/tighten axes_grid.
* :ghpull:`16942`: Cleanup and avoid refleaks OSX Timer__timer_start.
* :ghpull:`16944`: TST: update default junit_family
* :ghpull:`16823`: Dedupe implementation of axes grid switching in toolmanager.
* :ghpull:`16951`: Cleanup dates docstrings.
* :ghpull:`16769`: Fix some small style issues
* :ghpull:`16936`: FIX: Plot is now rendered with correct inital value
* :ghpull:`16937`: Making sure to keep over/under/bad in cmap resample/reverse.
* :ghpull:`16915`: Tighten/cleanup wx backend.
* :ghpull:`16923`: Test the macosx backend on Travis.
* :ghpull:`15369`: Update style docs
* :ghpull:`16893`: Robustify ``AffineBase.__eq__`` against comparing to other classes.
* :ghpull:`16904`: Turn fontdict & minor into kwonly parameters for set_{x,y}ticklabels.
* :ghpull:`16917`: Add test for close_event.
* :ghpull:`16920`: Remove unused _read_ppm_image from macosx.m.
* :ghpull:`16877`: Cleanup new_fixed_axis examples.
* :ghpull:`15049`: Annotate argument in axes class match upstream
* :ghpull:`16774`: Cleanup demo_axes_hbox_divider.
* :ghpull:`16873`: More fixes to pydocstyle D403 (First word capitalization)
* :ghpull:`16896`: set_tick_params(label1On=False) should also make offset text invisible.
* :ghpull:`16907`: Fix typo in implementation of quit_all_keys.
* :ghpull:`16900`: Document and test common_texification()
* :ghpull:`16902`: Remove dot from suffix in testing.compare.
* :ghpull:`16828`: Use more _setattr_cm, thus fix Text('').get_window_extent(dpi=...)
* :ghpull:`16901`: Cleanup many docstrings.
* :ghpull:`16840`: Deprecate support for Qt4.
* :ghpull:`16899`: Remove optional returns from TriAnalyzer._get_compressed_triangulation.
* :ghpull:`16618`: Use SubplotSpec row/colspans more, and deprecate get_rows_columns.
* :ghpull:`15392`: Autoscale for ax.arrow()
* :ghpull:`14626`: Add support for minor ticks in 3d axes.
* :ghpull:`16897`: Add back missing import.
* :ghpull:`14725`: Move the debug-mode TransformNode.write_graphviz out.
* :ghpull:`15437`: Improve handling of alpha when saving to jpeg.
* :ghpull:`15606`: Simplify OldAutoLocator and AutoDateLocator.
* :ghpull:`16863`: Shortcut for closing all figures
* :ghpull:`16876`: Small cleanups to dviread.
* :ghpull:`15680`: Use more kwonly arguments, less manual kwargs-popping.
* :ghpull:`15318`: Deprecate unused rcParams["animation.html_args"].
* :ghpull:`15303`: Make it possible to use rc_context as a decorator.
* :ghpull:`16890`: Enables hatch alpha on SVG
* :ghpull:`16887`: Shorter event mocking in tests.
* :ghpull:`16881`: Validate tickdir strings
* :ghpull:`16846`: Disconnect manager when resizing figure for animation saving.
* :ghpull:`16871`: Shorter Path import in setupext.
* :ghpull:`16892`: Warn in the docs that MouseEvent.key can be wrong.
* :ghpull:`16209`: Dedupe boilerplate for "adoption" of figure into pyplot.
* :ghpull:`16098`: Deprecate parameter props of Shadow
* :ghpull:`15747`: Move Text init to end of Annotation init.
* :ghpull:`15679`: np.concatenate cleanups.
* :ghpull:`16778`: Remove more API deprecated in 3.1(part 7)
* :ghpull:`16886`: Finish removing mentions of idle_event.
* :ghpull:`16882`: Fix trivial docstring typos.
* :ghpull:`16874`: Fix pydocstyle D209 (Multi-line docstring closing separate line)
* :ghpull:`14044`: Remove font preamble caching in TexManager.
* :ghpull:`16724`: Fixed incorrect colour in ErrorBar when Nan value is presented
* :ghpull:`15254`: Propagate signature-modifying decorators to pyplot wrappers.
* :ghpull:`16868`: Update release guide
* :ghpull:`14442`: In the build, declare all (compulsory) extension modules together.
* :ghpull:`16866`: Cleanup/update deprecations.
* :ghpull:`16850`: use validate_[cap/join]style
* :ghpull:`16858`: Fix various numpydoc style issues
* :ghpull:`16848`: Cleanup CI setup
* :ghpull:`16845`: Fix checking of X11 builds with PySide2.
* :ghpull:`14199`: Deprecate Path helpers in bezier.py
* :ghpull:`16838`: Inline some more kwargs into setup.py's setup() call.
* :ghpull:`16841`: Cleanup errorbar subsampling example
* :ghpull:`16839`: spines doc cleanup
* :ghpull:`16844`: fix example hist(density=...)
* :ghpull:`16827`: Fix warnings in doc examples
* :ghpull:`16772`: Remove more API deprecated in 3.1
* :ghpull:`16822`: fix bug where make_compound_path kept all STOPs
* :ghpull:`16819`: Destroy figures by manager instance, not by number.
* :ghpull:`16824`: Deprecate NavigationToolbar2QT.parent.
* :ghpull:`16825`: Don't use deprecated Gtk add_with_viewport.
* :ghpull:`16816`: Merge v3.2.x into master
* :ghpull:`16786`: Simple cleanups to formatters.
* :ghpull:`16807`: Update barchart_demo.
* :ghpull:`16804`: Deprecate some mathtext glue helper classes.
* :ghpull:`16808`: One more instance of check_in_list.
* :ghpull:`16802`: Fix incorrect super class of VCentered.
* :ghpull:`16789`: Update markup for collections docstrings.
* :ghpull:`16781`: Update image tutorial wrt. removal of native png handler.
* :ghpull:`16787`: Avoid vstack() when possible.
* :ghpull:`16689`: Add a fast path for NumPy arrays to Collection.set_verts
* :ghpull:`15373`: Further shorten quiver3d computation...
* :ghpull:`16780`: Don't import rcParams but rather use mpl.rcParams (part 3)
* :ghpull:`16775`: Cleanup axes_divider examples.
* :ghpull:`15949`: Simplify implementation of SubplotTool.
* :ghpull:`14869`: Deduplicate code for text-to-path conversion in svg backend.
* :ghpull:`16527`: Validate positional parameters of add_subplot()
* :ghpull:`15622`: Cleanup mpl_toolkits locators.
* :ghpull:`16744`: Reword axes_divider tutorial.
* :ghpull:`16746`: Reword colorbar-with-axes-divider example.
* :ghpull:`15211`: Various backend cleanups.
* :ghpull:`15890`: Remove API deprecated in 3.1 (part 2)
* :ghpull:`16757`: Simplify interactive zoom handling.
* :ghpull:`15515`: Combine withEffect PathEffect definitions.
* :ghpull:`15977`: pgf backend cleanups.
* :ghpull:`15981`: Reuse colorbar outline and patch when updating the colorbar.
* :ghpull:`14852`: Use Path.arc() to interpolate polar arcs.
* :ghpull:`16686`: Deprecate Substitution.from_params.
* :ghpull:`16675`: Vectorize patch extraction in Axes3D.plot_surface
* :ghpull:`15846`: Standardize signature mismatch error messages.
* :ghpull:`16740`: Fix type of ``dpi`` in docstrings.
* :ghpull:`16741`: Dedupe RGBAxes examples.
* :ghpull:`16755`: Reword docstring of panning callbacks, and pass them a MouseButton.
* :ghpull:`16749`: Document behavior of savefig("extensionless-name").
* :ghpull:`16754`: Cleanup image.py.
* :ghpull:`14606`: Generic cleanup to hist().
* :ghpull:`16692`: Allow MarkerStyle instances as input for lines
* :ghpull:`15479`: Cleanup axes_rgb.
* :ghpull:`16617`: Use Path(..., closed=True) more.
* :ghpull:`16710`: Make format_coord messagebox resize with the window and the content in osx backend
* :ghpull:`16681`: Simplify docstring interpolation for Box/Arrow/ConnectionStyles.
* :ghpull:`16576`: Deprecate arg-less calls to subplot_class_factory (and similar factories)
* :ghpull:`16652`: Deprecate {Locator,Axis}.{pan,zoom}.
* :ghpull:`16596`: Deprecate dviread.Encoding.
* :ghpull:`16231`: Deprecate JPEG-specific kwargs and rcParams to savefig.
* :ghpull:`16636`: Deprecate autofmt_xdate(which=None) to mean which="major".
* :ghpull:`16644`: Deprecate validate_webagg_address.
* :ghpull:`16619`: Fix overindented lines.
* :ghpull:`15233`: backend_ps cleanup.
* :ghpull:`16604`: Deprecate more rc validators.
* :ghpull:`16601`: Small unrelated cleanups.
* :ghpull:`16584`: Rename font_bunch to psfont in textpath.
* :ghpull:`16023`: Dedupe implementations of fill_between & fill_betweenx.
* :ghpull:`16485`: Simplify validate_color_for_prop_cycle.
* :ghpull:`16285`: Deprecate RendererCairo.font{weights,angles}
* :ghpull:`16410`: Fix support for empty usetex strings.
* :ghpull:`11644`: Add feature to fallback to stix font in mathtext
* :ghpull:`16537`: Delay checking for existence of postscript distillers.
* :ghpull:`16351`: Group all init of Legend.legendPatch together.
* :ghpull:`15988`: Refactor Annotation properties.
* :ghpull:`16421`: Shorten the type1-to-unicode name table.
* :ghpull:`16200`: Deprecate Artist.{set,get}_contains.
* :ghpull:`15828`: Deprecate support for dash-offset = None.
* :ghpull:`16338`: Document SymmetricalLogLocator parameters.
* :ghpull:`16504`: DOC: more pcolor fixes
* :ghpull:`15996`: Cleanup axes_size.
* :ghpull:`16108`: Deprecate DraggableBase.on_motion_blit.
* :ghpull:`16706`: Fix exception causes all over the codebase
* :ghpull:`15855`: Simplify 3d axes callback setup.
* :ghpull:`16219`: Simplify CallbackRegistry pickling.
* :ghpull:`16002`: relax two test tolerances on x86_64
* :ghpull:`16063`: Make the signature of Axes.draw() consistent with Artist.draw().
* :ghpull:`16177`: Further simplify setupext.
* :ghpull:`16191`: Make Figure._axobservers a CallbackRegistry.
* :ghpull:`16698`: Small edits to toolkits docs.
* :ghpull:`15430`: Simplify setupext.download_or_cache.
* :ghpull:`16694`: Lower Text's FontProperties priority when updating
* :ghpull:`16511`: Add more detailed kwargs docstrings to Axes methods.
* :ghpull:`16653`: Tutorials: make path/URL option clearer in matplotlibrc tutorial
* :ghpull:`16697`: Update docstrings for plot_directive.
* :ghpull:`16684`: Fix exception causes in 19 modules
* :ghpull:`16674`: Docstring + import cleanups to legend.py.
* :ghpull:`16683`: Turn mathtext.GlueSpec into a (private) namedtuple.
* :ghpull:`16660`: Cleanup fancybox_demo.
* :ghpull:`16691`: Clarify tiny comment re: AnnotationBbox constructor.
* :ghpull:`16676`: Cleanup animation docstrings.
* :ghpull:`16673`: DOC: correct title_fontsize docstring
* :ghpull:`16669`: DOC: update doc release guide
* :ghpull:`16563`: Parametrize imshow antialiased tests.
* :ghpull:`16658`: In docs, add multi-axes connectionpatches to Figure, not Axes.
* :ghpull:`16647`: Update annotation tutorial.
* :ghpull:`16638`: Remove unused, outdated division operators on jpl_units.
* :ghpull:`16509`: Add custom math fallback
* :ghpull:`16609`: Fix exception causes in rcsetup.py
* :ghpull:`16637`: Update docstrings in figure.py.
* :ghpull:`16534`: DOC: MaxNLocator and contour/contourf doc update (replaces #16428)
* :ghpull:`16597`: close #16593: setting ecolor turns off color cycling
* :ghpull:`16615`: Update custom boxstyles example.
* :ghpull:`16610`: Added graphviz_docs to conf.py
* :ghpull:`16608`: Stricter validation of rcParams["axes.axisbelow"].
* :ghpull:`16614`: Cleanup quiver3d examples.
* :ghpull:`16556`: Make backend_ps test robust against timestamp changes in ghostscript.
* :ghpull:`16602`: Cleanup testing.compare.
* :ghpull:`16575`: Style fix for dynamic axes subclass generation in mpl_toolkits.
* :ghpull:`16587`: Remove warnings control from tests.py.
* :ghpull:`16599`: Cleanup dolphin example.
* :ghpull:`16586`: Deprecate recursionlimit kwarg to matplotlib.test().
* :ghpull:`16595`: Minor docstring/references update.
* :ghpull:`16579`: Update usetex_fonteffects example.
* :ghpull:`16578`: Use rc() less often in examples/tutorials.
* :ghpull:`16572`: Remove some remnants of hist{,2d}(normed=...).
* :ghpull:`16491`: Expire the _rename_parameters API changes.
* :ghpull:`14592`: In SecondaryAxis.set_functions, reuse _set_scale's parent scale caching.
* :ghpull:`16279`: STY: Fix underindented continuation lines.
* :ghpull:`16549`: Improve documentation for examples/widgets/textbox.py
* :ghpull:`16560`: Update URL to pyparsing.
* :ghpull:`16292`: More edits to Normalize docstrings.
* :ghpull:`16536`: API/TST: minimum versions
* :ghpull:`16559`: 3D example avoid using statefull .gca()
* :ghpull:`16553`: DOC: clarify the expected shapes of eventplot input
* :ghpull:`16535`: Clarify docs of num parameter of plt.figure()
* :ghpull:`16547`: Reformat/reword mathtext docstrings.
* :ghpull:`16545`: Add a smoketest for ps.usedistiller="xpdf".
* :ghpull:`16529`: Deprecate toggling axes navigatability using the keyboard.
* :ghpull:`16521`: Remove more API deprecated in 3.1.
* :ghpull:`16481`: Update set_thetalim documentation
* :ghpull:`16524`: Cleanup docstrings
* :ghpull:`16540`: Cleanup imports
* :ghpull:`16429`: CI: update codecov
* :ghpull:`16533`: Recommend to amend pull requests
* :ghpull:`16531`: Also deprecate ignorecase ValidateInStrings.
* :ghpull:`16428`: DOC: MaxNLocator and contour/contourf doc update
* :ghpull:`16525`: Don't import rcParams but rather use mpl.rcParams (part 2)
* :ghpull:`16528`: Improve test failure messages on warnings.
* :ghpull:`16393`: Shorten PyFT2Font_get_charmap.
* :ghpull:`16483`: Deprecate most ValidateInStrings validators.
* :ghpull:`16523`: Reorder mathtext rcparams in matplotlibrc template.
* :ghpull:`16520`: Update a comment re: minimum version of numpy working around bug.
* :ghpull:`16522`: Fix deprecation warning
* :ghpull:`16515`: Fix doc for set_{x,y}label, and then some more.
* :ghpull:`16516`: Fixes to boxplot() docstring & error messages.
* :ghpull:`16508`: Multi-dim transforms are non-separable by default.
* :ghpull:`16507`: Factor out common parts of ``__str__`` for Transform subclasses.
* :ghpull:`16514`: Various delayed PR reviews
* :ghpull:`16512`: Fix a bunch of random typos.
* :ghpull:`16510`: Doc markup cleanups.
* :ghpull:`16500`: Dedupe timer attribute docs.
* :ghpull:`16503`: DOC: suppress warning on pcolor demo
* :ghpull:`16495`: Deemphasize basemap in user-facing docs.
* :ghpull:`16484`: Don't forget to set stretch when exporting font as svg reference.
* :ghpull:`16486`: Simplify validate_color, and make it slightly stricter.
* :ghpull:`16246`: Avoid using FontProperties when not needed.
* :ghpull:`16432`: Prefer geomspace() to logspace().
* :ghpull:`16099`: Consistently name callback arguments event instead of evt
* :ghpull:`16477`: Remove some APIs deprecated in mpl3.1.
* :ghpull:`16475`: Use vlines() and plot(), not stem(), in timeline example.
* :ghpull:`16474`: Switch default of stem(use_line_collection=...) to True.
* :ghpull:`16467`: Convert named_colors example to use Rectangle
* :ghpull:`16047`: Remove more API deprecated in 3.1
* :ghpull:`16373`: Fix usetex_baseline_test.
* :ghpull:`16433`: Simplify demo_curvelinear_grid2.
* :ghpull:`16472`: Fix mplot3d projection
* :ghpull:`16092`: Deprecate clear_temp param/attr of FileMovieWriter.
* :ghpull:`15504`: Warn when trying to start a GUI event loop out of the main thread.
* :ghpull:`15023`: Simplify formatting of matplotlibrc.template.
* :ghpull:`13535`: Validate inputs to ScalarMappable constructor
* :ghpull:`16469`: FIX: colorbar minorticks when rcParams['x/ytick.minor.visible'] = True
* :ghpull:`16401`: BLD: Auto-detect PlatformToolset
* :ghpull:`16024`: Keep parameter names in preprocess_data.
* :ghpull:`13390`: Make sure that scatter3d copies its inputs.
* :ghpull:`16107`: Deprecate DraggableBase.artist_picker.
* :ghpull:`16455`: Update some docstrings in colors.py
* :ghpull:`16456`: Enable more font_manager tests to be run locally.
* :ghpull:`16459`: Update backend dependency docs.
* :ghpull:`16444`: Dedupe spectral plotting tests.
* :ghpull:`16460`: Remove some mentions of avconv, following its deprecation.
* :ghpull:`16443`: Parametrize some spectral tests.
* :ghpull:`16204`: Expire deprecation of \mathcircled
* :ghpull:`16446`: Replace matshow baseline test by check_figures_equal.
* :ghpull:`16418`: Backend timer simplifications.
* :ghpull:`16454`: Use pytest.raises(match=...)
* :ghpull:`14916`: Make kwargs names in scale.py not include the axis direction.
* :ghpull:`16258`: ENH: add shading='nearest' and 'auto' to ``pcolormesh``
* :ghpull:`16228`: Allow directly passing explicit font paths.
* :ghpull:`16445`: Remove a bunch of imports-within-tests.
* :ghpull:`16440`: Expire deprecation of \stackrel.
* :ghpull:`16439`: Rework pylab docstring.
* :ghpull:`16441`: Rework pylab docstring.
* :ghpull:`16442`: Expire deprecation of \stackrel.
* :ghpull:`16365`: TST: test_acorr (replaced image comparison with figure comparion)
* :ghpull:`16206`: Expire deprecation of \stackrel
* :ghpull:`16437`: Rework pylab docstring.
* :ghpull:`8896`: Fix mplot3d projection
* :ghpull:`16430`: Remove unnecessary calls to np.array in examples.
* :ghpull:`16407`: Remove outdated comment re: PYTHONHASHSEED and pytest.
* :ghpull:`16225`: Cleanup animation examples.
* :ghpull:`16336`: Include axline() in infinite lines example
* :ghpull:`16395`: Add set/get for ellipse width/height
* :ghpull:`16431`: CI: add py38 to azure matrix
* :ghpull:`16415`: Expire some APIs deprecated in mpl3.1.
* :ghpull:`16425`: MNT: rename internal variable
* :ghpull:`16427`: Style-fix some examples and update .flake8 per-file-ignores.
* :ghpull:`16423`: Slightly improve streamplot code legibility.
* :ghpull:`16414`: DOC: Fix ``axes:plot`` method docstring verb tense
* :ghpull:`16408`: Deprecate avconv animation writers.
* :ghpull:`16406`: Don't import rcParams but rather use mpl.rcParams.
* :ghpull:`16326`: Cleanup stack
* :ghpull:`16193`: Catch shadowed imports in style checks.
* :ghpull:`16374`: Log about font manager generation beforehand.
* :ghpull:`16372`: Dedupe ImageGrid doc from tutorial and docstring.
* :ghpull:`16380`: "gif" third-party package added to the extension page
* :ghpull:`16327`: Cleanup list copying
* :ghpull:`16366`: Special-case usetex minus to zero depth.
* :ghpull:`16350`: TST: Improved test (getting rid of image comparison test for test_titletwiny)
* :ghpull:`16359`: Make Text.update_from copy usetex state.
* :ghpull:`16355`: typo in ``ticker.ScalarFormatter`` doc
* :ghpull:`15440`: Use rcParams to control default "raise window" behavior (Qt,Gtk,Tk,Wx)
* :ghpull:`16302`: Cleanup Legend._auto_legend_data.
* :ghpull:`16329`: ENH: add zorder kwarg to contour clabel (and a better default value for zorder)
* :ghpull:`16341`: Remove mention of now-removed --verbose-foo flags.
* :ghpull:`16265`: Fix spy(..., marker=<not-None>, origin="lower")
* :ghpull:`16333`: Document animation HTML writer.
* :ghpull:`16334`: Fix doc regarding deprecation of properties.
* :ghpull:`16335`: Fix some more missing references.
* :ghpull:`16304`: Simplify Legend.get_children.
* :ghpull:`16309`: Remove duplicated computations in Axes.get_tightbbox.
* :ghpull:`16314`: Avoid repeatedly warning about too many figures open.
* :ghpull:`16319`: Put doc for XAxis befor YAxis and likewise for XTick, YTick.
* :ghpull:`16313`: Cleanup constrainedlayout_guide.
* :ghpull:`16312`: Remove unnecessary Legend._approx_text_height.
* :ghpull:`16307`: Cleanup axes_demo.
* :ghpull:`16303`: Dedupe Legend.draw_frame which is the same as set_frame_on.
* :ghpull:`16261`: TST: move the Qt-specific handling to conftest
* :ghpull:`16297`: DOC: fix description of vmin/vmax in scatter
* :ghpull:`16288`: Remove the private, unused _csv2rec.
* :ghpull:`16281`: Update/cleanup pgf tutorial.
* :ghpull:`16283`: Cleanup backend_agg docstrings.
* :ghpull:`16282`: Replace "unicode" by "str" in docs, messages when referring to the type.
* :ghpull:`16289`: axisartist tutorial markup fixes.
* :ghpull:`16293`: Revert "Fix doc CI by pointing to dev version of scipy docs."
* :ghpull:`16287`: Improve markup for rcParams in docs.
* :ghpull:`16271`: Clean up and clarify Normalize docs
* :ghpull:`16290`: Fix doc CI by pointing to dev version of scipy docs.
* :ghpull:`16276`: Cleanup docstring of print_figure, savefig.
* :ghpull:`16277`: Prefer using MouseButton to numeric values in docs and defaults.
* :ghpull:`16270`: numpydoc-ify SymLogNorm
* :ghpull:`16274`: Tiny cleanups to set_xlabel(..., loc=...).
* :ghpull:`16273`: DOC: Changing the spelling of co-ordinates.
* :ghpull:`15974`: Enable set_{x|y|}label(loc={'left'|'right'|'center'}...)
* :ghpull:`16248`: Update matplotlib.__doc__.
* :ghpull:`16262`: Dedupe update of rcParams["backend"] in use() and in switch_backend()
* :ghpull:`9629`: Make pcolor(mesh) preserve all data
* :ghpull:`16254`: DOC: pdf.preamble --> pgf.preamble
* :ghpull:`16245`: Cleanup image docs
* :ghpull:`16117`: CI: Unify required dependencies installation
* :ghpull:`16240`: Cleanup custom_scale example.
* :ghpull:`16227`: Make Animation.repeat_delay an int, not an int-or-None.
* :ghpull:`16242`: CI: Remove PYTHONUNBUFFERED=1 on Appveyor
* :ghpull:`16183`: Remove some baseline images for plot() tests.
* :ghpull:`16229`: And more missing refs.
* :ghpull:`16215`: Concise dates test
* :ghpull:`16233`: Reword ScalarFormatter docstrings.
* :ghpull:`16218`: Cleanup animation docs.
* :ghpull:`16172`: And more missing references.
* :ghpull:`16205`: Deprecate the empty matplotlib.compat.
* :ghpull:`16214`: Fix overindented line in AnchoredOffsetbox doc.
* :ghpull:`15943`: Deprecate the TTFPATH & AFMPATH environment variables.
* :ghpull:`16039`: Deprecate unused features of normalize_kwargs.
* :ghpull:`16202`: Remove outdated statement in tight_layout guide.
* :ghpull:`16201`: UnCamelCase examples.
* :ghpull:`16194`: Numpydoc ticklabel_format.
* :ghpull:`16195`: Numpydoc ContourSet.find_nearest_contour.
* :ghpull:`16198`: Remove em dash
* :ghpull:`16199`: Do not use camel case for variables in examples
* :ghpull:`15644`: Rewrite cursor example to include speedup possibilities
* :ghpull:`16196`: Cleanup patches docstrings.
* :ghpull:`16184`: Expire a mpl2.2-deprecated API
* :ghpull:`16188`: Remove ref. to non-existent method in animation tests.
* :ghpull:`16170`: Deprecate old and little used formatters.
* :ghpull:`16187`: Fix overly long lines in examples & tutorials.
* :ghpull:`15982`: Colorbar cleanup.
* :ghpull:`16154`: Deprecate setting pickradius via set_picker
* :ghpull:`16174`: Numpydocify artist.getp().
* :ghpull:`16165`: Remove rcParams deprecated in mpl3.0/3.1.
* :ghpull:`16141`: Update _base.py
* :ghpull:`16169`: Add missing spaces after commas.
* :ghpull:`15847`: Remove some dead branches from texmanager code.
* :ghpull:`16125`: Fix more missing references again.
* :ghpull:`16150`: Simplify transforms addition.
* :ghpull:`16152`: Inline _init_axes_pad into Grid.__init__.
* :ghpull:`16129`: Deprecate some Transform aliases in scale.py.
* :ghpull:`16162`: (Mostly) avoid the term "command" in the docs.
* :ghpull:`16159`: Simple cleanups for contour.py.
* :ghpull:`16164`: Fix trivial typo in deprecation warning message.
* :ghpull:`16160`: Cleanup hist() docstring.
* :ghpull:`16149`: DOC: reword density desc in ``ax.hist``
* :ghpull:`16151`: Remove outdated comment re: blended transforms.
* :ghpull:`16102`: Rework example "Scatter Star Poly" to "Marker examples"
* :ghpull:`16134`: Validate Line2D pickradius when setting it, not when reading it.
* :ghpull:`15019`: Add step option where='edges' to facilitate pre-binned hist plots
* :ghpull:`16142`: Avoid using np.r\_, np.c\_.
* :ghpull:`16146`: Remove LICENSE_CONDA.
* :ghpull:`16133`: Reword docstring of Line2D.contains.
* :ghpull:`16120`: Minor fontproperty fixes.
* :ghpull:`15670`: Reuse Grid.__init__ in ImageGrid.__init__.
* :ghpull:`16025`: Deprecate update_datalim_bounds.
* :ghpull:`16001`: Remove parameters deprecated in 3.1
* :ghpull:`16049`: Add __repr__ to SubplotSpec.
* :ghpull:`16100`: Consistently name event callbacks on_[event]
* :ghpull:`16106`: In DraggableLegend, inherit DraggableBase.artist_picker.
* :ghpull:`16109`: Name Axes variables ax instead of a
* :ghpull:`16115`: Fix more missing references.
* :ghpull:`16096`: Deprecate unused parameters
* :ghpull:`16085`: Improve docstrings in offsetbox.py
* :ghpull:`16097`: Cleanup unused variables
* :ghpull:`16101`: Fix incorrect doc regarding projections.
* :ghpull:`16095`: Deprecate MovieWriter.{exec,args}_key, making them private.
* :ghpull:`16078`: Refactor a bit animation start/save interaction.
* :ghpull:`16081`: Delay resolution of animation extra_args.
* :ghpull:`16088`: Use C++ true/false in ttconv.
* :ghpull:`16082`: Defaut to writing animation frames to a temporary directory.
* :ghpull:`16070`: Make animation blit cache robust against 3d viewpoint changes.
* :ghpull:`5056`: MNT: more control of colorbar with CountourSet
* :ghpull:`16051`: Deprecate parameters to colorbar which have no effect.
* :ghpull:`16045`: Use triple-double-quotes for docstrings
* :ghpull:`16076`: Cleanup path_editor example.
* :ghpull:`16059`: Simplify colorbar test.
* :ghpull:`16072`: Cleanup category.py docstrings.
* :ghpull:`15769`: scatter() should not rescale if norm is given
* :ghpull:`16060`: Cleanup pcolor_demo.
* :ghpull:`16057`: Trivial docstring fix for cbook.deprecated.
* :ghpull:`16043`: Simplify some comparisons
* :ghpull:`16044`: Code style cleanup
* :ghpull:`15894`: rcsetup cleanups.
* :ghpull:`16050`: Unbreak CI.
* :ghpull:`16034`: Update comments re: colors._vector_magnitude.
* :ghpull:`16035`: Make eventplot use the standard alias resolution mechanism.
* :ghpull:`15798`: Better default behavior for boxplots when rcParams['lines.marker'] is set
* :ghpull:`16004`: Improve documentation of text module
* :ghpull:`15507`: Use FixedFormatter only with FixedLocator
* :ghpull:`16008`: Remove unused imports
* :ghpull:`16036`: Rely on pytest to record warnings, rather than doing it manually.
* :ghpull:`15734`: Fix home/forward/backward buttons for 3d plots.
* :ghpull:`16038`: Cleanup contour_demo.
* :ghpull:`15998`: Join marker reference and marker fiillstyle reference
* :ghpull:`15976`: Cleanup span_where.
* :ghpull:`15990`: Remove deprecated support for setting single property via multiple aliases
* :ghpull:`15940`: Some unicode-support related cleanups.
* :ghpull:`15836`: Compactify a bit the EventCollection tests.
* :ghpull:`16013`: Relayout some conditions in axes_grid.
* :ghpull:`16010`: Inherit the Artist.draw docstring in subclasses.
* :ghpull:`16017`: Document support for no-args plt.subplot() call.
* :ghpull:`16014`: Simplify calls to AxesGrid/ImageGrid.
* :ghpull:`16012`: Normalize aspect="equal" to aspect=1 in the setter.
* :ghpull:`15997`: Shorten wx _onMouseWheel.
* :ghpull:`15993`: Style fixes for axes_divider.
* :ghpull:`15989`: Simplify Artist.update.
* :ghpull:`16015`: Some small extension cleanups
* :ghpull:`16011`: Replace axes_size.Fraction by multiplication.
* :ghpull:`15719`: Templatize spectral helpers.
* :ghpull:`15995`: Remove toolkit functions deprecated in 3.1
* :ghpull:`16003`: prevent needless float() conversion
* :ghpull:`16000`: De-deprecate \*min/\*max parameters to set_x/y/zlim()
* :ghpull:`15684`: Avoid RuntimeError at wx exit.
* :ghpull:`15992`: Avoid using np.matrix.
* :ghpull:`15961`: Be more opinionated for setting up a dev env.
* :ghpull:`15991`: Avoid setting dtypes as strings...
* :ghpull:`15985`: Remove unnecessary :func:, :meth: from examples markup.
* :ghpull:`15983`: Fix some examples docstrings.
* :ghpull:`15979`: Remove references to scipy cookbook.
* :ghpull:`15966`: FIX: check subplot kwargs
* :ghpull:`15947`: Merge the two usetex demos.
* :ghpull:`15939`: Exceptions should start with a capital letter
* :ghpull:`15948`: Use rc_context more.
* :ghpull:`15962`: Add tests for IndexFormatter
* :ghpull:`15965`: Test registering cmaps
* :ghpull:`15950`: Remove deprecated TextWithDash
* :ghpull:`15942`: Update docs of type1font
* :ghpull:`15927`: Trying to set the labels without setting ticks through pyplot now raises TypeError*
* :ghpull:`15944`: Minor doc cleanups
* :ghpull:`15945`: Do not use "object" or "instance" when documenting types
* :ghpull:`15897`: Cleanup TriAnalyzer docs
* :ghpull:`15777`: Don't bother disconnecting idle_draw at gtk shutdown.
* :ghpull:`15929`: Remove unused cbook._lockstr.
* :ghpull:`15935`: Raise an ValueError when Axes.pie accepts negative values #15923
* :ghpull:`15895`: Deprecate unused illegal_s attribute.
* :ghpull:`15900`: Rewrite test_cycles to avoid image comparison tests.
* :ghpull:`15892`: Update docs of backend_manager
* :ghpull:`15878`: Remove API deprecated in 3.1
* :ghpull:`15928`: DOC: use markers as slanted breaks in broken axis example
* :ghpull:`14659`: Update some widget docstrings.
* :ghpull:`15919`: Remove mod_python specific code.
* :ghpull:`15883`: Improve error when passing 0d array to scatter().
* :ghpull:`15907`: More docstrings cleanup.
* :ghpull:`15906`: Cleanup legend docstrings.
* :ghpull:`15776`: Improve doc for data kwarg.
* :ghpull:`15904`: Deemphasize ACCEPTS blocks in documenting_mpl docs.
* :ghpull:`15891`: Mark self.* expressions in docstrings as literal
* :ghpull:`15875`: Deprecate implicit creation of colormaps in register_cmap()
* :ghpull:`15885`: Cleanup text.py docstrings.
* :ghpull:`15888`: Cleanup backend_bases docs.
* :ghpull:`15887`: Fix AnnotationBbox docstring.
* :ghpull:`15858`: Avoid some uses of len-1 tuples.
* :ghpull:`15873`: Standardize parameter types in docs
* :ghpull:`15874`: Cleanup backend_bases docs
* :ghpull:`15876`: Deprecate case-insensitive capstyles and joinstyles.
* :ghpull:`15877`: Suppress exception chaining on rc validator failure.
* :ghpull:`15880`: Use True/False instead of 0/1 as booleans in backend_ps.
* :ghpull:`15827`: Fix validation of linestyle in rcparams and cycler.
* :ghpull:`15850`: Docstrings cleanup in matplotlib.axes
* :ghpull:`15853`: np.abs -> (builtins).abs
* :ghpull:`15854`: Simplify Axes3D init.
* :ghpull:`15822`: More cleanup defaults in docstrings
* :ghpull:`15838`: Remove some references to Py2.
* :ghpull:`15834`: Optimize colors.to_rgba.
* :ghpull:`15830`: Allow failure on nightly builds.
* :ghpull:`15788`: Fixes pyplot xticks() and yticks() by allowing setting only the labels
* :ghpull:`15805`: Improve docs on figure size
* :ghpull:`15783`: Fix stepfilled histogram polygon bottom perimeter
* :ghpull:`15812`: Cleanup defaults in docstrings
* :ghpull:`15804`: Cleanup many docstrings.
* :ghpull:`15790`: Update docs of PolyCollection
* :ghpull:`15792`: Cleanup dviread docs.
* :ghpull:`15801`: Cleanup some references to rcParams in docs.
* :ghpull:`15787`: Cleanup ``Colormap.__call__``.
* :ghpull:`15766`: Shorten description on search page
* :ghpull:`15786`: Slightly clarify the implementation of safe_masked_invalid.
* :ghpull:`15767`: Update badges in README.rst
* :ghpull:`15778`: Fix typos and comma splices in legend guide
* :ghpull:`15775`: Some pathlibification.
* :ghpull:`15772`: Directly dedent the spectral parameter docs.
* :ghpull:`15765`: Reword some docstrings.
* :ghpull:`15686`: Simplify and unify character tracking in pdf and ps backends (with linked fonts)
* :ghpull:`9321`: Add Axes method for drawing infinite lines
* :ghpull:`15749`: Fix travis links in README
* :ghpull:`15673`: Rely on findfont autofallback-to-default in pdf/ps backends.
* :ghpull:`15740`: Small animation cleanup.
* :ghpull:`15739`: ImageMagick animators now can use extra_args
* :ghpull:`15591`: Remove FAQ on 'Search' -- already referenced in search file
* :ghpull:`15629`: Consistently use realpaths to build XObject names
* :ghpull:`15696`: Improve mathtext.fontset docs and fix :mathmpl: cache bug.
* :ghpull:`15721`: Render default values in :rc: directive as literal
* :ghpull:`15720`: Suppress triage_tests warning on Py3.8.
* :ghpull:`15709`: Make 3d plot accept scalars as arguments.
* :ghpull:`15711`: Don't explicitly list scalez kwarg in Axes3D constructor and docs.
* :ghpull:`14948`: Simplify Tick and Axis initialization.
* :ghpull:`15693`: Also test PySide2 on CI.
* :ghpull:`15701`: Tried to solve Issue #15650: Print URL when webbrowser.open Fails
* :ghpull:`15704`: Fix more broken refs.
* :ghpull:`15687`: Add tooltips to HTML animation controls
* :ghpull:`15592`: Offset text position
* :ghpull:`15697`: Fix some broken doc refs.
* :ghpull:`15700`: Parametrize some spectral tests.
* :ghpull:`15699`: Fix some incorrect ValueErrors.
* :ghpull:`15698`: Bump numpy dependency to >=1.15.
* :ghpull:`15694`: Handle upcoming deprecation of np.float.
* :ghpull:`15691`: Correctly handle high dpi in Pillow animation writer.
* :ghpull:`15676`: Doc adopt nep29
* :ghpull:`15692`: Update FUNDING.yml
* :ghpull:`15645`: Bump minimal numpy version to 1.12.
* :ghpull:`15646`: Hide sphinx-gallery config comments
* :ghpull:`15642`: Remove interpolation="nearest" from most examples.
* :ghpull:`15671`: Don't mention tcl in tkagg commments anymore.
* :ghpull:`15607`: Simplify tk loader.
* :ghpull:`15651`: Simplify axes_pad handling in axes_grid.
* :ghpull:`15652`: Remove mention of Enthought Canopy from the docs.
* :ghpull:`15655`: Remove outdated license files.
* :ghpull:`15639`: Simplify axes_grid.Grid/axes_grid.ImageGrid construction.
* :ghpull:`15640`: Remove some commented-out code from axes_grid.
* :ghpull:`15643`: Fix examples claiming matplotlib can't plot np.datetime64.
* :ghpull:`15375`: Add note to hist docstring about speed
* :ghpull:`15461`: Fix invalid checks for axes_class parameter in ImageGrid.
* :ghpull:`15635`: Deprecate "U" mode passed to cbook.to_filehandle().
* :ghpull:`15563`: In backend_pgf, directly open subprocess in utf8 mode.
* :ghpull:`15462`: Simplify azure setup.
* :ghpull:`13075`: Remove logic for optionally building Agg and TkAgg.
* :ghpull:`15262`: Declare qt figureoptions tool in toolitems.
* :ghpull:`15292`: Shorten RendererWx.get_wx_font.
* :ghpull:`15569`: Allow linking against a system qhull as well.
* :ghpull:`15589`: Make sure that figures are closed when check_figures_equal finishes
* :ghpull:`15465`: Validate and simplify set_tick_params(which=...)
* :ghpull:`15090`: Coerce MxNx1 images into MxN images for imshow
* :ghpull:`15578`: BLD: set the max line length on the flake8 config
* :ghpull:`15564`: Use True instead of 1 as filternorm default
* :ghpull:`15536`: Add a backend kwarg to savefig.
* :ghpull:`15571`: Cleanup following using Pillow as universal image reader
* :ghpull:`15476`: Default to local_freetype builds.
* :ghpull:`15557`: Skip failing pgf test when sfmath.sty is not present.
* :ghpull:`15555`: Add pgf to list of builtin backends in docs.
* :ghpull:`15534`: BLD: update pillow dependency
* :ghpull:`15427`: Separate plots using #### in demo_fixed_size_axes.py
* :ghpull:`15505`: Cleanup axisartist tutorial.
* :ghpull:`15506`: Rename locator.den to the clearer locator.nbins in mpl_toolkits.
* :ghpull:`15502`: Get rid of trivial compiler warning.
* :ghpull:`15451`: Ci py38
* :ghpull:`15484`: Cleanup docs regarding compilers.
* :ghpull:`15467`: Validate locator_params(axis=...)
* :ghpull:`15330`: Add axes method for drawing infinite lines.
* :ghpull:`15482`: Trivial style fixes to constrained_layout.
* :ghpull:`15418`: Use correct pip/pytest on azure
* :ghpull:`15466`: Update tick_params() docs
* :ghpull:`15463`: Remove staticbuild option from setup.cfg.template.
* :ghpull:`15378`: Don't link ft2font to zlib by default.
* :ghpull:`15270`: When no gui event loop is running, propagate callback exceptions.
* :ghpull:`15447`: Move testing of Py3.8 to Travis.
* :ghpull:`15431`: Fix range(len()) usages
* :ghpull:`15390`: Simplify implementation of vectorized date operations.
* :ghpull:`15403`: Fix DeprecationWarning in nightly testing
* :ghpull:`15394`: Deprecate {NonUniformImage,PcolorImage}.is_grayscale.
* :ghpull:`15400`: Updated INSTALL.rst to correct install commands
* :ghpull:`13788`: Autoscale for ax.arrow()
* :ghpull:`15367`: Update the readme on providing  API changes
* :ghpull:`15193`: Switch to using pillow for png as well.
* :ghpull:`15346`: vectorized calc_arrow loop in quiver
* :ghpull:`15011`: Adding example for drawstyle
* :ghpull:`15371`: Deprecate Colorbar.config_axis()
* :ghpull:`15361`: Update next API changes to new structure
* :ghpull:`15274`: NavigationToolbar2Tk: make packing optional.
* :ghpull:`15158`: Change the way API changes are documented
* :ghpull:`15356`: Fix broken imports.
* :ghpull:`15200`: Simplify SubplotParams.update().
* :ghpull:`15210`: Explicitly list allowed "unused" imports, remove the rest.
* :ghpull:`15348`: Some figure and related docs cleanup
* :ghpull:`13355`: Simplify and generalize BezierSegment.
* :ghpull:`14917`: ENH: box aspect for axes
* :ghpull:`14949`: Use fix_minus in format_data_short.
* :ghpull:`15341`: Move non-gui warning message to backend_bases.
* :ghpull:`15335`: Add discourse link to readme
* :ghpull:`15293`: Fixes for wx savefig dialog.
* :ghpull:`15324`: Update PR guidelines
* :ghpull:`15301`: Update colorbar docs
* :ghpull:`15340`: Always attach a manager attribute (possibly None) on canvas.
* :ghpull:`15319`: Make validate_movie_writer actually check registered writers.
* :ghpull:`10973`: PGF: Replace \pgfimage by \includegraphics to fix \import regression
* :ghpull:`15302`: fix warning used by cbook.warn_deprecated()
* :ghpull:`15321`: Sort missing_references.json.
* :ghpull:`15290`: Unify fig.delaxes(ax) and ax.remove().
* :ghpull:`15309`: Simplify sca().
* :ghpull:`15201`: Autogenerate gca(), gci() from boilerplate.py.
* :ghpull:`15305`: Autogenerate footer Copyright year
* :ghpull:`15294`: Replace custom logging in wx by stdlib logging.
* :ghpull:`15288`: More properties aliases.
* :ghpull:`15286`: throw deprecation warning on empty call to fig.add_axes()
* :ghpull:`15282`: Colorbar cleanup.
* :ghpull:`15250`: Cleanup font_manager.
* :ghpull:`13581`: Cleanup _pylab_helpers.
* :ghpull:`15273`: DOC: don't use term units in transform tutorial
* :ghpull:`15263`: Correctly setup comparisons in test_compare_images.
* :ghpull:`15226`: Turn gtk3 pan/zoom button into togglable buttons.
* :ghpull:`14609`: Simplify implementation of set_{x,y}bound.
* :ghpull:`15261`: Change layout of test_triager to avoid cropping images.
* :ghpull:`15236`: Dedupe SubplotSpec construction in mpl_toolkits.
* :ghpull:`14130`: Add decorator to inherit keyword-only deprecations
* :ghpull:`15249`: In findfont(fallback_to_default=False), throw if default font is missing
* :ghpull:`15175`: Simplify pdf image output.
* :ghpull:`7506`: [WIP] Add Axes method for drawing infinite lines.

Issues (198):

* :ghissue:`16501`: Setting a thetalim > 2pi gives odd results
* :ghissue:`15035`: security exposure in the packaged jquery library
* :ghissue:`10375`: Coordinate text wrapping in navigation toolbar
* :ghissue:`10720`: Option to set the text color in legend to be same as the line
* :ghissue:`17868`: plt.bar with nan input fails rendering in notebook using 3.3.0rc1
* :ghissue:`17773`: gtk3 rubberband is invisible
* :ghissue:`5726`: Cursor displays x, y coordinates with too much or too little precision
* :ghissue:`5164`: Sort out qt_compat
* :ghissue:`17905`: macosx backend warns when using the zoom method
* :ghissue:`17703`: QuadMesh.get_clim changed behavior in 3.3.0rc1
* :ghissue:`17875`: animation.writers['ffmpeg']" is hung when run in background.
* :ghissue:`17591`: Single-character colors do not match long names
* :ghissue:`16905`: if pie normalizes depends on input values
* :ghissue:`17829`: trunk fails to build in AIX
* :ghissue:`17820`: Regression: _reshape_2D no longer preserves the shape of lists of lists of one scalar each
* :ghissue:`17807`: "%matplotlib notebook" Download is Noise After Interacting with Plot
* :ghissue:`17763`: matplotlib.use('agg', force=True) does not ignore unavailable configured backend
* :ghissue:`17586`: Surprising datetime autoscaling after passing empty data
* :ghissue:`17792`: when using plt.tight_layout(), figure title overlaps subplot titles
* :ghissue:`17736`: ax.set_xticklabels([]) for categorical plots is broken in 3.3.0rc1
* :ghissue:`17757`: Plotting Hist with histtype 'stepfilled' does not respect bottom correctly
* :ghissue:`17744`: BUG: AttributeError: 'FigureCanvasBase' object has no attribute 'print_png' in 3.3rc0
* :ghissue:`17730`: Using backend Template and plt.tight_layout raises UnboundLocalError
* :ghissue:`17716`: Error using "set_window_title" for canvas via backend_qt5agg
* :ghissue:`17681`: PDF cannot be built due to Zenodo SVGs
* :ghissue:`17627`: AttributeError: 'Figure' object has no attribute '_cachedRenderer'
* :ghissue:`17658`: Feature request: Add advanced zoom and inspect feature to GUI for more productivity
* :ghissue:`17629`: Use of Python deprecated APIs.
* :ghissue:`17670`: BUG: Setting ticksize xx-small broken by #17348
* :ghissue:`17673`: RuntimeError: latex was not able to process the following string: b'$\\\\mathdefault{-2}$'
* :ghissue:`17412`: Document the dependency on the type1ec LaTeX package
* :ghissue:`17643`: AutoDateLocator docs has a typo
* :ghissue:`9118`: make TeXManager more user-configurable
* :ghissue:`11131`: Make pyplot.pause not give focus to the figure window
* :ghissue:`17646`: more conservative setattr_cm broke mplcairo
* :ghissue:`17634`: Cannot copy LinearSegmentedColormap
* :ghissue:`16496`: Single path optimisation for Collection w/ offsets broken
* :ghissue:`192`: Savefig does not issue a warning on a non-existent keyword n
* :ghissue:`17624`: _DummyAxis needs a __name__ attribute for ScalarFormatter
* :ghissue:`16910`: Axes.imshow draws invalid color at value is 0 when max of 'X' not equal to vmax
* :ghissue:`17637`: streamplot and sticky edges interaction
* :ghissue:`17633`: Stackplot fails for small numbers
* :ghissue:`17616`: waitforbuttonpress in Linux
* :ghissue:`17615`: small bug in documentation of backend.FigureCanvasBase.start_event_loop
* :ghissue:`17093`: Zero size figure use case
* :ghissue:`17608`: How avoid PyQt5 to crash when I move Qslitter to the edge with a matplotlib figure in it?
* :ghissue:`9829`: Vertices clipped for certain markers when plotting more than two points and saving as pdf
* :ghissue:`15815`: bar3d color length bug
* :ghissue:`15376`: ScalarFormatter.set_powerlimits documentation seems inconsistent
* :ghissue:`17595`: Master doc builds broken
* :ghissue:`16482`: Pyplot hlines and vlines do not use the 'lines.color' property in rcParams by default
* :ghissue:`16388`: rethink how we display DOI svg badges
* :ghissue:`17172`: set_aspect for 3D plots
* :ghissue:`16463`: Jupyter "inline" backend seems to misinterpret "figsize" with Axes3D
* :ghissue:`17527`: The markers are not hollow when I use ax.scatter() and set markers.MarkerStyle()'s fillstyle to 'none'. My usage is wrong?
* :ghissue:`7491`: sort out if the high-resolution ellipse code still works
* :ghissue:`17398`: Plotting an error band along a curve
* :ghissue:`8550`: Matplotlib chooses the wrong font for unrecognized weights
* :ghissue:`8788`: Font issue: findfonts should differentiate between thin and regular ttf fonts
* :ghissue:`10194`: legend is not present in the generated image if I use 'tight' for bbox_inches
* :ghissue:`17336`: set_url without effect for instances of Line2D
* :ghissue:`9695`: set_url() without effect in the plot for instances of Tick
* :ghissue:`17192`: How to change the thickness of the marker "x" when using scatter?
* :ghissue:`17507`: pyplot.savefig() throwing warning suggesting a bug (possibly in figManger)
* :ghissue:`17502`: dict unpacking broken for ``.plot`` in 3.2
* :ghissue:`15546`: plt.imshow: clip_on=False has no effect
* :ghissue:`17023`: DOC: Tutorial/Sample plots should use same fig/axis creation method
* :ghissue:`7537`: Conflict between different AGG static libraries in a same binary
* :ghissue:`16836`: Dropping support for PyQt4; preparing support for PyQt6.
* :ghissue:`17455`: LightSource.shade fails on a masked array
* :ghissue:`16353`: BUG: VisibleDeprecationWarning in boxplot
* :ghissue:`11820`: Compressed Triangulation Masking in CubicTriInterpolator
* :ghissue:`11823`: Animation Examples
* :ghissue:`15410`: Change in OSX Catalina makes matplotlib + multiprocessing crash
* :ghissue:`17467`: Bug Report: saved Figure ignores figure.facecolor
* :ghissue:`17343`: Regression in add_subplot..
* :ghissue:`7093`: ordering issues between ``set_xmargin`` and ``set_xscale``
* :ghissue:`13971`: Unnecessary drawing with NbAgg
* :ghissue:`17432`: Scatter accepts marker=MarkerStyle(), but plot does not
* :ghissue:`15675`: Boxplot line color with style dark_background should be bright
* :ghissue:`5962`: No output from pyplot on cygwin64 python3 virtualenv
* :ghissue:`17393`: TexManager.get_rgba fails
* :ghissue:`5830`: Incorrect overlap of markers in scatter3D
* :ghissue:`11937`: Limiting ticks on colorbar axes falsify tick labels.
* :ghissue:`17354`: Converter detection fails for inkscape if on headless system without DISPLAY
* :ghissue:`17352`: Zoom In-Out not behaving  as expected in QT backend example
* :ghissue:`15409`: Datetime plot fails with 'Agg' backend in interactive mode
* :ghissue:`14155`: Adding GridSpec.subplots?
* :ghissue:`16583`: matplotlibrc validates some parameters wrongly
* :ghissue:`16946`: Pick_event on AnnotationBbox fires at wrong position
* :ghissue:`15131`: set_size_inches doesn't resize window on macosx backend
* :ghissue:`7619`: Figure background colors
* :ghissue:`15899`: Describe possible kwargs that may be input into a function
* :ghissue:`17304`: constrained-layout gives wrong results when explicitly equal width ratios are set
* :ghissue:`17295`: DOC: https://matplotlib.org/api/_as_gen/matplotlib.quiver.Quiver.html
* :ghissue:`17294`: DOC: matplotlib.axes.Axes.annotate.html
* :ghissue:`17290`: backend_svg fails with dashed line style
* :ghissue:`16677`: tmp_config_or_cache_dir atexit cleanup fails after forks()
* :ghissue:`15091`: Turbo color map
* :ghissue:`7372`: Moving get_ax and do_event to testing
* :ghissue:`15225`: Show offset text on subplots after sharing axis
* :ghissue:`7138`: misplaced spines in dates plot
* :ghissue:`17243`: Misleading error message in _parse_scatter_color_args
* :ghissue:`16461`: Hexbin if singular and mincnt used
* :ghissue:`14596`: forward port jquery removal from ipympl
* :ghissue:`17217`: Transform operators are not publicly documented....
* :ghissue:`2253`: matplotlib makes python lose focus
* :ghissue:`7184`: margins does not handle bézier curves
* :ghissue:`16830`: ``_path.get_extents`` does not correctly handle bezier curves
* :ghissue:`17176`: Print figure using PS backend is needlessly slow
* :ghissue:`17141`: flake8-docstrings does not check all of our requirements
* :ghissue:`16567`: Let legend get the handles from the provided objects if not specified explicitly.
* :ghissue:`16805`: Titles cannot be padded to negative numbers anymore.
* :ghissue:`17114`: ``add_axes`` shows deprecation warning when called with only ``kwarg``\s
* :ghissue:`16885`: Change return type get_{x,y}ticklabels to plain list
* :ghissue:`17044`: widgets.TextBox continuously creates new text objects and linecollection objects.
* :ghissue:`17066`: documentation of animation contains non-working code example
* :ghissue:`16588`: Rename next_api_changes to api_changes_3.x (whatever number makes sense)
* :ghissue:`17015`: ``get_major_ticks`` docs missing return type
* :ghissue:`16976`: Thin line color distortion on large scale
* :ghissue:`16934`: gtk3 window immediately resizes down to zero-height upon showing up.
* :ghissue:`16941`:  test_determinism_check is failing (sometimes)
* :ghissue:`16982`: pyplot.rgrids don't do anything
* :ghissue:`16952`: How to solve an error of "ValueError: Key backend: Unrecognized backend string '"agg"'
* :ghissue:`15272`: Axes.violinplot has small issue in using pandas.DataFrame without index 0.
* :ghissue:`16926`: tk window immediately resizes down to zero-height upon showing up.
* :ghissue:`16919`: wx backends don't send close_event if window is closed via "q" keypress
* :ghissue:`16854`: small typo in the documentation
* :ghissue:`16895`: offset text still visible with ImageGrid axis "L"
* :ghissue:`12712`: Autoscale does not work for ax.arrow()
* :ghissue:`14208`: shift + w does not close all figures (has no effect)
* :ghissue:`15745`: Failed to add annotate to figure
* :ghissue:`11432`: Pressing the "1" key kills the zoom/pan tool
* :ghissue:`13799`: BUG: incorrect error bar colors when NaN values are present
* :ghissue:`16185`: hist demo appears to incorrectly mention ``normed`` and something odd about ``density`` as well.
* :ghissue:`15203`: Closing figures is done by number
* :ghissue:`16016`: Better argument checking of subplot definition in ``add_subplot()``
* :ghissue:`15980`: Is the reset of the colorbar's edgecolor when updating the corresponding image clim wanted behaviour?
* :ghissue:`16718`: Float figure DPI
* :ghissue:`16498`: long string of format_coord in osx backend
* :ghissue:`8405`: BUG: PDF export seems wrong with dash sequences that include a None offset
* :ghissue:`8619`: Feature request: allow mathtext fallback font other than Computer Modern for custom mathtext setup
* :ghissue:`14996`: format error saving eps figure using custom linestyle
* :ghissue:`16493`: Example/tutorials warn due to new pcolormesh shading
* :ghissue:`16022`: Cleanup Artist.draw() signatures
* :ghissue:`16389`: “Size” ignored if placed before fontproperties
* :ghissue:`16687`: Creating a figure of size (0, 0) raises an error
* :ghissue:`12729`: Docs for contour levels argument is incorrect
* :ghissue:`16593`: specifying ecolor in errobar turns off cycling
* :ghissue:`15621`: secondary_xaxis doesn't seem to use formatters
* :ghissue:`16116`: travis36minver.txt needs an update
* :ghissue:`16546`: Problem with eventplot - error message claims events & lineoffsets are unequal sizes
* :ghissue:`16462`: Allow wedges of polar plots to include theta = 0.
* :ghissue:`15142`: pyplot.annotate() API deprecation
* :ghissue:`16479`: font-stretch property missing in svg export
* :ghissue:`14304`: 'NSWindow drag regions should only be invalidated on the Main Thread!' - macos/python
* :ghissue:`12085`: Tcl_AsyncDelete: async handler deleted by the wrong thread
* :ghissue:`14669`: cm.ScalarMappable should fail early when norm input is wrong
* :ghissue:`16468`: incorrect cbar minor ticks for extend regions when x/ytick.minor.visible is True
* :ghissue:`16243`: windows builds: devenv freetype /update appears not to have an effect
* :ghissue:`11525`: Axes3D scatter plot for Numpy arrays in F-order does not give correct z-values
* :ghissue:`8894`: mplot3d projection results in non-orthogonal axes
* :ghissue:`1104`: Resizing a GUI window with Axes3D
* :ghissue:`16371`: Incomplete documentation in axes_grid1
* :ghissue:`6323`: Vertical alignment of tick labels with usetex=True
* :ghissue:`7957`: clabel not respecting zorder parameter
* :ghissue:`16252`: axes.spy plotting function doesn't respect origin='lower' kwarg when marker is not None
* :ghissue:`16299`: The interactive polar plot animation's axis label won't scale.
* :ghissue:`15182`: More tests ``ConciseDateFormatter`` needed
* :ghissue:`16140`: Unclear Documentation for get_xticklabels
* :ghissue:`16147`: pp.hist parmeter 'density' does not scale data appropriately
* :ghissue:`16069`: matplotlib glitch when rotating interactively a 3d animation
* :ghissue:`14603`: Scatterplot: should vmin/vmax be ignored when a norm is specified?
* :ghissue:`15730`: Setting lines.marker = s in matplotlibrc also sets markers in boxplots
* :ghissue:`11178`: home/back/forward buttons do nothing in 3d mode
* :ghissue:`14520`: pylab with wx backend not exiting cleanly
* :ghissue:`15964`: Guard ``plt.subplot`` kwargs a bit better?
* :ghissue:`15404`: Add python 3.8 tests
* :ghissue:`15773`: Warning:... GLib.source_remove(self._idle_draw_id) when using plt.savefig()
* :ghissue:`15923`: pie takes negative values
* :ghissue:`10317`: Setting plt.rc('text', usetex=True) after ticker.ScalarFormatter(useMathText=True) causes Error
* :ghissue:`15825`: Customised dashed linstyle in matplotlib.cycler throws ValueError when using in Axes.set_prop_cycle
* :ghissue:`9792`: Error with linestyles rcParams entries under the form (on, off, ...) and a style context manager
* :ghissue:`15782`: Invalid polygon in stepfilled histogram when bottom is set
* :ghissue:`15628`: Invalid unicode characters in PDF when font is a symlink
* :ghissue:`8577`: mplot3D scalar arguments for plot function
* :ghissue:`15650`: URL is not shown when webagg failed to open the browser.
* :ghissue:`5238`: the offset of the scientific notation in xaxis stays at bottom when axis is set to top
* :ghissue:`15678`: Error at save animation with pillow
* :ghissue:`15079`: check_figures_equal decorator reuses figures if called multiple times inside a single test.
* :ghissue:`15089`: Coerce MxNx1 images into MxN images for imshow
* :ghissue:`5253`: abline() - for drawing arbitrary lines on a plot, given specifications.
* :ghissue:`15165`: Switch to requiring Pillow rather than having our own png wrapper?
* :ghissue:`15280`: Add pull request checklist to Reviewers Guidlines
* :ghissue:`15289`: cbook.warn_deprecated() should warn with a MatplotlibDeprecationWarning not a UserWarning
* :ghissue:`15285`: DOC: make copy right year auto-update
* :ghissue:`15059`: fig.add_axes() with no arguments silently does nothing
* :ghissue:`14546`: Setting lines.markeredgecolor in rcParams affects the ticks' mark color too
